Module blaxel.core.sandbox.client.types
=======================================
Contains some shared types for properties

Classes
-------

`File(payload: <class 'BinaryIO'>, file_name: str | None = None, mime_type: str | None = None)`
:   Contains information for file uploads
    
    Method generated by attrs for class File.

    ### Instance variables

    `file_name: str | None`
    :

    `mime_type: str | None`
    :

    `payload: <class 'BinaryIO'>`
    :

    ### Methods

    `to_tuple(self) ‑> tuple[str | None, typing.BinaryIO, str | None]`
    :   Return a tuple representation that httpx will accept for multipart/form-data

`Response(status_code: http.HTTPStatus, content: bytes, headers: MutableMapping[str, str], parsed: ~T | None)`
:   A response from an endpoint
    
    Method generated by attrs for class Response.

    ### Ancestors (in MRO)

    * typing.Generic

    ### Instance variables

    `content: bytes`
    :

    `headers: MutableMapping[str, str]`
    :

    `parsed: ~T | None`
    :

    `status_code: http.HTTPStatus`
    :

`Unset()`
: